@@ -4,6 +4,7 @@ from types import SimpleNamespace
 
 import hashlib
 import hmac
+import secrets
 
 
 class Basic(logging.Formatter):
@@ -12,8 +13,8 @@ class Basic(logging.Formatter):
 	"""
 	def __init__(self, params):
 
-		self.secret = params["secret"]
-		self.prevLine = params["seed"]
+		self.secret = params.get("secret", secrets.token_urlsafe(128))
+		self.prevLine = params.get("seed", secrets.token_urlsafe())
 
 		format = params.get("format", "%(timestamp)s %(levelLetters)s %(fileLine)-15s %(funcName)-15s %(message)-60s |%(signature)s")
 		# Have a check for presence of signature ?
@@ -33,9 +34,8 @@ class Basic(logging.Formatter):
 		record.fileLine = record.filename  + ':' + str(record.lineno)
 		record.timestamp = self.makeTimestamp(record)
 
-		logLine = self.stringify(record)
-		self.prevLine = logLine
-		return logLine
+		self.prevLine = self.stringify(record)
+		return self.prevLine
 
 
 	def makeTimestamp(self, record):
@@ -79,8 +79,14 @@ class Basic(logging.Formatter):
 	@staticmethod
 	def extractSignature(line):
 		return line[line.rindex('|') + 1:]
+	
+	def verify(self, prevLine, line):
+		# Checks the line's signature matches prevLine's content
+		aStoredSign = self.__class__.extractSignature(line)
+		aComputedSign = Basic.sign(prevLine, self.secret)
+		return hmac.compare_digest(aStoredSign, aComputedSign)
 
-	def setField(self, **kwargs):
+	def setFields(self, **kwargs):
 		# Keep previous for scoped restoration
 		previousCtx = {**self.context}
 		self.context.update(kwargs)
