@@ -1,3 +1,3 @@
 #__all__ = ["Basic", "Json"]
-from .Basic import Basic
+from .Basic import *
 from .Json import *
